"use client";
import { DataTableColumnHeader } from "./data-table-column-header";
import { CellAction } from "./cell-action";

import { ColumnDef } from "@tanstack/react-table";
import {
  HoverCard,
  HoverCardContent,
  HoverCardTrigger,
} from "@/components/ui/hover-card";
import { Checkbox } from "@/components/ui/checkbox";
import { Organization } from "@/types/organization";
import { formatDate } from "@/lib/format-date";
import { ApiCommunication } from "@/types/api-communication";
import { ScrollArea, ScrollBar } from "../ui/scroll-area";

export const columns: ColumnDef<ApiCommunication>[] = [
  {
    id: "select",
    header: ({ table }) => (
      <Checkbox
        checked={
          table.getIsAllPageRowsSelected() ||
          (table.getIsSomePageRowsSelected() && "indeterminate")
        }
        onCheckedChange={(value) => table.toggleAllPageRowsSelected(!!value)}
        aria-label="Select all"
        className="translate-y-[2px]"
      />
    ),
    cell: ({ row }) => (
      <Checkbox
        checked={row.getIsSelected()}
        onCheckedChange={(value) => row.toggleSelected(!!value)}
        aria-label="Select row"
        className="translate-y-[2px]"
      />
    ),
    enableSorting: false,
    enableHiding: false,
  },

  {
    accessorKey: "id",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="PT" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p>{row.getValue("id")}</p>
            </HoverCardTrigger>
            <HoverCardContent>{row.getValue("id")}</HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },
  {
    accessorKey: "messages",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="MESSAGES" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p className="max-w-[200px] truncate font-medium">
                {row.getValue("messages")}
              </p>
            </HoverCardTrigger>
            <HoverCardContent className="p-0 h-72 w-72 lg:h-96 lg:w-96">
              <ScrollArea className="h-72 w-72 p-4 lg:h-96 lg:w-96">
                {JSON.stringify(row.getValue("messages"), null, 2)}
                <ScrollBar orientation="horizontal" />
              </ScrollArea>
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },
  {
    accessorKey: "completion",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="COMPLETION" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p className="max-w-[200px] truncate font-medium">
                {row.getValue("completion")}
              </p>
            </HoverCardTrigger>
            <HoverCardContent className="p-0 h-72 w-72 lg:h-96 lg:w-96">
              <ScrollArea className="h-72 w-72 p-4 lg:h-96 lg:w-96">
                {row.getValue("completion")}
                <ScrollBar orientation="horizontal" />
              </ScrollArea>
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },
  {
    accessorKey: "pt",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="PT" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p>{row.getValue("pt")}</p>
              {/* <p className="max-w-[100px] truncate font-medium">
                {row.getValue("pt")}
              </p> */}
            </HoverCardTrigger>
            <HoverCardContent
            // className="p-0"
            >
              {/* <ScrollArea className="w-64 p-4"> */}
              {row.getValue("pt")}
              {/* <ScrollBar orientation="horizontal" /> */}
              {/* </ScrollArea> */}
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },
  {
    accessorKey: "ct",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="CT" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p>{row.getValue("ct")}</p>
              {/* <p className="max-w-[100px] truncate font-medium">
                {row.getValue("ct")}
              </p> */}
            </HoverCardTrigger>
            <HoverCardContent
            // className="p-0"
            >
              {/* <ScrollArea className="w-64 p-4"> */}
              {row.getValue("ct")}
              {/* <ScrollBar orientation="horizontal" /> */}
              {/* </ScrollArea> */}
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },
  {
    accessorKey: "tt",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="TT" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p>{row.getValue("tt")}</p>
              {/* <p className="max-w-[100px] truncate font-medium">
                {row.getValue("tt")}
              </p> */}
            </HoverCardTrigger>
            <HoverCardContent
            // className="p-0"
            >
              {/* <ScrollArea className="w-64 p-4"> */}
              {row.getValue("tt")}
              {/* <ScrollBar orientation="horizontal" /> */}
              {/* </ScrollArea> */}
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },
  {
    accessorKey: "status",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="STATUS" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p>{row.getValue("status")}</p>
            </HoverCardTrigger>
            <HoverCardContent>{row.getValue("status")}</HoverCardContent>
          </HoverCard>
        </div>
      );
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },
  {
    accessorKey: "evaluation",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="EVALUATION" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              {/* <p>{row.getValue("evaluation")}</p> */}
              <p className="max-w-[200px] truncate font-medium">
                {row.getValue("evaluation")}
              </p>
            </HoverCardTrigger>
            <HoverCardContent className="p-0 h-52">
              <ScrollArea className="h-52 p-4">
                {row.getValue("evaluation")}
                <ScrollBar orientation="horizontal" />
              </ScrollArea>
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },

  {
    accessorKey: "created_at",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="CREATED AT" />
    ),
    cell: ({ row }) => {
      return <p className="w-fit">{formatDate(row.getValue("created_at"))}</p>;
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },

  {
    id: "actions",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="ACTIONS" />
    ),
    cell: ({ row }) => <CellAction data={row.original} />,
  },
];
