"use client";

import { Cross2Icon } from "@radix-ui/react-icons";
import { Table } from "@tanstack/react-table";

import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
// import { DataTableViewOptions } from "./components/data-table-view-options"

import { DataTableFacetedFilter } from "./data-table-faceted-filter";
import { DataTableViewOptions } from "./data-table-view-options";
import { ApiCommunication } from "@/types/api-communication";

interface DataTableToolbarProps<TData> {
  table: Table<TData>;
  data: ApiCommunication[];
}

export function DataTableToolbar<TData>({
  table,
  data,
}: DataTableToolbarProps<TData>) {
  const isFiltered = table.getState().columnFilters.length > 0;

  const statusFilterOptions = Array.from(
    new Set(data.map((d) => d.status.toLocaleLowerCase()))
  ).map((v) => ({
    label: v,
    value: v,
  }));
  // const statusFilterOptions = Array.from(
  //   new Set(data.map((d) => d.status.toLocaleLowerCase()))
  // ).map((v) => ({
  //   label: v.slice(0, 1).toLocaleUpperCase() + v.slice(1),
  //   value: v.slice(0, 1).toLocaleUpperCase() + v.slice(1),
  // }));

  console.log(statusFilterOptions);

  return (
    <div className="flex items-center justify-between">
      <div className="flex flex-1 items-center gap-2 flex-wrap">
        <Input
          placeholder="Search messages..."
          value={
            (table.getColumn("messages")?.getFilterValue() as string) ?? ""
          }
          onChange={(event: any) =>
            table.getColumn("messages")?.setFilterValue(event.target.value)
          }
          className="h-8 w-[150px] lg:w-[250px]"
        />
        <Input
          placeholder="Search completion..."
          value={
            (table.getColumn("completion")?.getFilterValue() as string) ?? ""
          }
          onChange={(event: any) =>
            table.getColumn("completion")?.setFilterValue(event.target.value)
          }
          className="h-8 w-[150px] lg:w-[250px]"
        />
        <Input
          placeholder="Search evaluation..."
          value={
            (table.getColumn("evaluation")?.getFilterValue() as string) ?? ""
          }
          onChange={(event: any) =>
            table.getColumn("evaluation")?.setFilterValue(event.target.value)
          }
          className="h-8 w-[150px] lg:w-[250px]"
        />

        {table.getColumn("status") && (
          <DataTableFacetedFilter
            column={table.getColumn("status")}
            title="Status"
            options={statusFilterOptions}
          />
        )}

        {isFiltered && (
          <Button
            variant="ghost"
            onClick={() => table.resetColumnFilters()}
            className="h-8 px-2 lg:px-3"
          >
            Reset
            <Cross2Icon className="ml-2 h-4 w-4" />
          </Button>
        )}
      </div>
      <DataTableViewOptions table={table} />
    </div>
  );
}
