"use client";
import { DataTableColumnHeader } from "./data-table-column-header";
import { CellAction } from "./cell-action";
import { ColumnDef } from "@tanstack/react-table";
import { Checkbox } from "@/components/ui/checkbox";
import { formatDate } from "@/lib/format-date";
import { Evaluation } from "@/types/evaluation";
import { Commit } from "@/types/commit";
import {
  HoverCard,
  HoverCardContent,
  HoverCardTrigger,
} from "../ui/hover-card";
import { ScrollArea, ScrollBar } from "../ui/scroll-area";

export const columns: ColumnDef<Commit>[] = [
  {
    id: "select",
    header: ({ table }) => (
      <Checkbox
        checked={
          table.getIsAllPageRowsSelected() ||
          (table.getIsSomePageRowsSelected() && "indeterminate")
        }
        onCheckedChange={(value) => table.toggleAllPageRowsSelected(!!value)}
        aria-label="Select all"
        className="translate-y-[2px]"
      />
    ),
    cell: ({ row }) => (
      <Checkbox
        checked={row.getIsSelected()}
        onCheckedChange={(value) => row.toggleSelected(!!value)}
        aria-label="Select row"
        className="translate-y-[2px]"
      />
    ),
    enableSorting: false,
    enableHiding: false,
  },

  {
    accessorKey: "hash",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="HASH" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p className="max-w-[250px] truncate font-medium">
                {row.getValue("hash")}
              </p>
            </HoverCardTrigger>
            <HoverCardContent className="p-0">
              <ScrollArea className="w-64 p-4">
                <p className="">{row.getValue("hash")}</p>
                <ScrollBar orientation="horizontal" />
              </ScrollArea>
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },

  {
    accessorKey: "status",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="STATUS" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("status")}</p>;
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },

  {
    accessorKey: "retryCount",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="RETRY COUNT" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("retryCount")}</p>;
    },
  },

  {
    accessorKey: "type",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="TYPE" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("type")}</p>;
    },
  },
  {
    accessorKey: "evaluation",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="EVALUATION" />
    ),
    cell: ({ row }) => {
      return (
        <div className="w-fit">
          <HoverCard>
            <HoverCardTrigger>
              <p className="max-w-[250px] truncate font-medium">
                {row.getValue("evaluation")}
              </p>
            </HoverCardTrigger>
            <HoverCardContent>
              <p className="whitespace-pre-wrap">
                {row.getValue("evaluation")}
              </p>
            </HoverCardContent>
          </HoverCard>
        </div>
      );
    },
  },

  {
    accessorKey: "commitDate",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="COMMIT DATE" />
    ),
    cell: ({ row }) => {
      return <p className="w-fit">{formatDate(row.getValue("commitDate"))}</p>;
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },

  {
    id: "actions",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="ACTIONS" />
    ),
    cell: ({ row }) => <CellAction data={row.original} />,
  },
];
